==> gnome-core-1.0.53.tar.gz: gnome-core-1.0.53/applets/tasklist/pixmaps.h <==
/* XPM */
static char * tasklist_close_xpm[] = {
"16 16 2 1",
" 	c None",
".	c #000000",
"                ",
"                ",
"                ",
"    .    ..     ",
"    ..  ....    ",
"     .. ...     ",
"     .....      ",
"      ...       ",
"      ....      ",
"     ......     ",
"     .. ....    ",
"    ..   ....   ",
"    .     ..    ",
"                ",
"                ",
"                "};
/* XPM */
static char * tasklist_iconify_xpm[] = {
"16 16 9 1",
" 	c None",
".	c #000000",
"+	c #E0E4E0",
"@	c #9CACA4",
"#	c #D0D4C4",
"$	c #909894",
"%	c #FFFFFF",
"&	c #990000",
"*	c #666666",
"                ",
" .............. ",
" .+@+@+@+@+@+@. ",
" .@#@#@#@#@#@$. ",
" .+@#@#@#@.@#@. ",
" .@#@#@#@...@$. ",
" .+@#@.@...@#@. ",
" .@#@#....@#@$. ",
" .+@#@...@#@#@. ",
" .@#@#....@#@$. ",
" .%%%@#@#@#@#@. ",
" .%&&*@#@#@#@$. ",
" .%&&*#@#@#@#@. ",
" .@***@$@$@$@$. ",
" .............. ",
"                "};
/* XPM */
static char * tasklist_restore_xpm[] = {
"16 16 9 1",
" 	c None",
".	c #000000",
"+	c #E0E4E0",
"@	c #9CACA4",
"#	c #D0D4C4",
"$	c #909894",
"%	c #FFFFFF",
"&	c #990000",
"*	c #666666",
"                ",
" .............. ",
" .+@+@+@+@+@+@. ",
" .@#@#@#@#@#@$. ",
" .+@#@#@....#@. ",
" .@#@#@#@...@$. ",
" .+@#@#@....#@. ",
" .@#@#@...@.@$. ",
" .+@#@...@#@#@. ",
" .@#@#@.@#@#@$. ",
" .%%%@#@#@#@#@. ",
" .%&&*@#@#@#@$. ",
" .%&&*#@#@#@#@. ",
" .@***@$@$@$@$. ",
" .............. ",
"                "};
/* XPM */
static char * tasklist_send_to_desktop_xpm[] = {
"16 16 11 1",
" 	c None",
".	c #000000",
"+	c #E0E4E0",
"@	c #9CACA4",
"#	c #909894",
"$	c #71736B",
"%	c #D0D4C4",
"&	c #080808",
"*	c #5B5D55",
"=	c #7B7E74",
"-	c #61635C",
" ...........    ",
" .+@+@+@+@#.    ",
" .@$.$@%@%@.    ",
" .+....&*@#.    ",
" .@=.-@%&%@.    ",
" .+@%@%@&@#.    ",
" .@%....&...... ",
" .#@.+@+&+@+@#. ",
" ....@%@&@%@%@. ",
"    .+&&&&&%@#. ",
"    .@%&&&%@%@. ",
"    .+@%&%@%@#. ",
"    .@%@%@%@%@. ",
"    .#@#@#@#@#. ",
"    ........... ",
"                "};
/* XPM */
static char * tasklist_shade_xpm[] = {
"16 16 5 1",
" 	c None",
".	c #000000",
"+	c #D89C90",
"@	c #A8444C",
"#	c #843424",
"                ",
" .............. ",
" .+@@@@@@@@@@#. ",
" .............. ",
"                ",
"       ..       ",
"      ....      ",
"     ......     ",
"       ..       ",
"       ..       ",
"       ..       ",
"       ..       ",
"                ",
"                ",
"                ",
"                "};
/* XPM */
static char * tasklist_stick_xpm[] = {
"20 20 34 1",
" 	c None",
".	c #000000",
"+	c #D3C9B2",
"@	c #C1B292",
"#	c #DBD2C0",
"$	c #DFD8C8",
"%	c #E5DFD2",
"&	c #DFD7C6",
"*	c #E8E2D7",
"=	c #CDC5AA",
"-	c #FFFFFF",
";	c #9C9077",
">	c #746F5F",
",	c #555144",
"'	c #F3F2EC",
")	c #534F42",
"!	c #8A8069",
"~	c #47443A",
"{	c #434136",
"]	c #A89B7F",
"^	c #E5E1D4",
"/	c #585447",
"(	c #514D40",
"_	c #877C66",
":	c #8E8977",
"<	c #656152",
"[	c #5F5A4C",
"}	c #E0DFDD",
"|	c #9F9B92",
"1	c #938E84",
"2	c #FBFAFA",
"3	c #D5CAB6",
"4	c #B3A588",
"5	c #92876F",
"                    ",
"        .....       ",
"       .+++@@.      ",
"      .#$%&+@@.     ",
"      .+**$++@.     ",
"       .+$%+@.      ",
"       .......      ",
"       .=-;>,.      ",
"       .='>>).      ",
"      ..=-!>~{.     ",
"     .].=^>>/(@.    ",
"     .@_:-]<[]@.    ",
"     .]$}|[[;@].    ",
"      .123@@@].     ",
"       ..445..      ",
"         ...        ",
"          .         ",
"          .         ",
"          .         ",
"                    "};
/* XPM */
static char * tasklist_unshade_xpm[] = {
"16 16 6 1",
" 	c None",
".	c #A8444C",
"+	c #000000",
"@	c #D89C90",
"#	c #D06458",
"$	c #843424",
"                ",
" ++++++++++++++ ",
" +@..........$+ ",
" ++++++++++++++ ",
"                ",
"       ++       ",
"       ++       ",
"       ++       ",
"       ++       ",
"     ++++++     ",
"      ++++      ",
"       ++       ",
"                ",
"                ",
"                ",
"                "};
/* XPM */
static char * tasklist_unstick_xpm[] = {
"20 20 41 1",
" 	c None",
".	c #000000",
"+	c #A89B7F",
"@	c #C1B292",
"#	c #938E84",
"$	c #DFD8C8",
"%	c #877C66",
"&	c #ADA89A",
"*	c #A49F91",
"=	c #FBFAFA",
"-	c #E0DFDD",
";	c #8E8977",
">	c #CDC5AA",
",	c #716E64",
"'	c #B5B0A0",
")	c #B9B4A4",
"!	c #888479",
"~	c #B3A588",
"{	c #D5CAB6",
"]	c #9F9B92",
"^	c #FFFFFF",
"/	c #E5E1D4",
"(	c #F3F2EC",
"_	c #5F5A4C",
":	c #746F5F",
"<	c #8A8069",
"[	c #9C9077",
"}	c #B5B1A2",
"|	c #B2AE9F",
"1	c #92876F",
"2	c #656152",
"3	c #585447",
"4	c #47443A",
"5	c #534F42",
"6	c #555144",
"7	c #ABA698",
"8	c #78756B",
"9	c #514D40",
"0	c #434136",
"a	c #9D998C",
"b	c #9B978A",
"                    ",
"                    ",
"                    ",
"                    ",
"                    ",
"       ...          ",
"      .+@+.    ..   ",
"     .#$%......&*.  ",
"     .=-;>>>>.,')!. ",
"    .~{]^/^(^.*''*. ",
" ....~@_+:<:[.}|'*. ",
"    .1@_2::::.*''*. ",
"     .@[_3456.!)78. ",
"     .+@+90....ab.  ",
"      .+@@.    ..   ",
"       ...          ",
"                    ",
"                    ",
"                    ",
"                    "};

/* XPM */
static char * tasklist_kill_xpm[] = {
"20 20 121 2",
"  	c None",
". 	c #000000",
"+ 	c #020202",
"@ 	c #030303",
"# 	c #1D1D1D",
"$ 	c #999999",
"% 	c #949494",
"& 	c #8D8D8D",
"* 	c #707070",
"= 	c #494949",
"- 	c #151515",
"; 	c #010101",
"> 	c #767676",
", 	c #A0A0A0",
"' 	c #C1C1C1",
") 	c #C0C0C0",
"! 	c #B4B4B4",
"~ 	c #9F9F9F",
"{ 	c #ACACAC",
"] 	c #868686",
"^ 	c #696969",
"/ 	c #515151",
"( 	c #E1E1E1",
"_ 	c #E3E3E3",
": 	c #DDDDDD",
"< 	c #D5D5D5",
"[ 	c #C4C4C4",
"} 	c #A6A6A6",
"| 	c #9B9B9B",
"1 	c #8F8F8F",
"2 	c #6A6A6A",
"3 	c #424242",
"4 	c #D8D8D8",
"5 	c #F9F9F9",
"6 	c #F7F7F7",
"7 	c #E8E8E8",
"8 	c #DFDFDF",
"9 	c #CDCDCD",
"0 	c #CACACA",
"a 	c #B2B2B2",
"b 	c #787878",
"c 	c #4B4B4B",
"d 	c #676767",
"e 	c #ABABAB",
"f 	c #EBEBEB",
"g 	c #555555",
"h 	c #A7A7A7",
"i 	c #D7D7D7",
"j 	c #5A5A5A",
"k 	c #2C2C2C",
"l 	c #2B2B2B",
"m 	c #3C3C3C",
"n 	c #B3B3B3",
"o 	c #535353",
"p 	c #131313",
"q 	c #121212",
"r 	c #202020",
"s 	c #CECECE",
"t 	c #4A4A4A",
"u 	c #111111",
"v 	c #0D0D0D",
"w 	c #0B0B0B",
"x 	c #4E4E4E",
"y 	c #7E7E7E",
"z 	c #434343",
"A 	c #191919",
"B 	c #0A0A0A",
"C 	c #050505",
"D 	c #414141",
"E 	c #EFEFEF",
"F 	c #3E3E3E",
"G 	c #060606",
"H 	c #040404",
"I 	c #242424",
"J 	c #353535",
"K 	c #929292",
"L 	c #575757",
"M 	c #595959",
"N 	c #F3F3F3",
"O 	c #CCCCCC",
"P 	c #6B6B6B",
"Q 	c #464646",
"R 	c #797979",
"S 	c #585858",
"T 	c #2D2D2D",
"U 	c #919191",
"V 	c #C7C7C7",
"W 	c #E9E9E9",
"X 	c #B6B6B6",
"Y 	c #323232",
"Z 	c #9A9A9A",
"` 	c #777777",
" .	c #262626",
"..	c #666666",
"+.	c #7F7F7F",
"@.	c #B8B8B8",
"#.	c #D9D9D9",
"$.	c #1A1A1A",
"%.	c #565656",
"&.	c #A4A4A4",
"*.	c #363636",
"=.	c #2E2E2E",
"-.	c #DBDBDB",
";.	c #4F4F4F",
">.	c #727272",
",.	c #A9A9A9",
"'.	c #DCDCDC",
").	c #DEDEDE",
"!.	c #C9C9C9",
"~.	c #7A7A7A",
"{.	c #474747",
"].	c #646464",
"^.	c #D2D2D2",
"/.	c #7B7B7B",
"(.	c #3A3A3A",
"_.	c #BFBFBF",
":.	c #3F3F3F",
"<.	c #D0D0D0",
"[.	c #C3C3C3",
"}.	c #B9B9B9",
"|.	c #A3A3A3",
"                                        ",
"              . . . + . @               ",
"          + # $ % $ & * = - .           ",
"        ; > , ' ) ! ~ { ] ^ / .         ",
"      . ^ $ ( _ : < [ } | 1 2 3 .       ",
"      . ^ 4 5 6 7 8 9 0 8 a b c .       ",
"    . d e f | g g h i < j k l c m .     ",
"    . j n o p p q r s t u v w # x .     ",
"    . x y z A B C D E F w G H I J .     ",
"    . g > K L M , N O % P Q R S T .     ",
"      . d U V W 6 X Y = Z U `  ..       ",
"      . ..+.@.#.W $.%.$.&.2 *.=..       ",
"        . ..+.0 -.$.) u | ;.l .         ",
"          . >.,.'.).!.~.$ {..           ",
"          . ' & ].^./.(._.:..           ",
"          . <.R B '.j . [./ .           ",
"          . }.].+ O = . |.Q .           ",
"            + .   H .   . .             ",
"                                        ",
"                                        "};

==> gnome-core-1.4.0.5.tar.gz: gnome-core-1.4.0.5/applets/tasklist/pixmaps.h <==
/* XPM */
static char * tasklist_close_xpm[] = {
"16 16 2 1",
" 	c None",
".	c #000000",
"                ",
"                ",
"                ",
"    .    ..     ",
"    ..  ....    ",
"     .. ...     ",
"     .....      ",
"      ...       ",
"      ....      ",
"     ......     ",
"     .. ....    ",
"    ..   ....   ",
"    .     ..    ",
"                ",
"                ",
"                "};
/* XPM */
static char * tasklist_iconify_xpm[] = {
"16 16 9 1",
" 	c None",
".	c #000000",
"+	c #E0E4E0",
"@	c #9CACA4",
"#	c #D0D4C4",
"$	c #909894",
"%	c #FFFFFF",
"&	c #990000",
"*	c #666666",
"                ",
" .............. ",
" .+@+@+@+@+@+@. ",
" .@#@#@#@#@#@$. ",
" .+@#@#@#@.@#@. ",
" .@#@#@#@...@$. ",
" .+@#@.@...@#@. ",
" .@#@#....@#@$. ",
" .+@#@...@#@#@. ",
" .@#@#....@#@$. ",
" .%%%@#@#@#@#@. ",
" .%&&*@#@#@#@$. ",
" .%&&*#@#@#@#@. ",
" .@***@$@$@$@$. ",
" .............. ",
"                "};
/* XPM */
static char * tasklist_restore_xpm[] = {
"16 16 9 1",
" 	c None",
".	c #000000",
"+	c #E0E4E0",
"@	c #9CACA4",
"#	c #D0D4C4",
"$	c #909894",
"%	c #FFFFFF",
"&	c #990000",
"*	c #666666",
"                ",
" .............. ",
" .+@+@+@+@+@+@. ",
" .@#@#@#@#@#@$. ",
" .+@#@#@....#@. ",
" .@#@#@#@...@$. ",
" .+@#@#@....#@. ",
" .@#@#@...@.@$. ",
" .+@#@...@#@#@. ",
" .@#@#@.@#@#@$. ",
" .%%%@#@#@#@#@. ",
" .%&&*@#@#@#@$. ",
" .%&&*#@#@#@#@. ",
" .@***@$@$@$@$. ",
" .............. ",
"                "};
/* XPM */
static char * tasklist_send_to_desktop_xpm[] G_GNUC_UNUSED = {
"16 16 11 1",
" 	c None",
".	c #000000",
"+	c #E0E4E0",
"@	c #9CACA4",
"#	c #909894",
"$	c #71736B",
"%	c #D0D4C4",
"&	c #080808",
"*	c #5B5D55",
"=	c #7B7E74",
"-	c #61635C",
" ...........    ",
" .+@+@+@+@#.    ",
" .@$.$@%@%@.    ",
" .+....&*@#.    ",
" .@=.-@%&%@.    ",
" .+@%@%@&@#.    ",
" .@%....&...... ",
" .#@.+@+&+@+@#. ",
" ....@%@&@%@%@. ",
"    .+&&&&&%@#. ",
"    .@%&&&%@%@. ",
"    .+@%&%@%@#. ",
"    .@%@%@%@%@. ",
"    .#@#@#@#@#. ",
"    ........... ",
"                "};
/* XPM */
static char * tasklist_shade_xpm[] = {
"16 16 5 1",
" 	c None",
".	c #000000",
"+	c #D89C90",
"@	c #A8444C",
"#	c #843424",
"                ",
" .............. ",
" .+@@@@@@@@@@#. ",
" .............. ",
"                ",
"       ..       ",
"      ....      ",
"     ......     ",
"       ..       ",
"       ..       ",
"       ..       ",
"       ..       ",
"                ",
"                ",
"                ",
"                "};
/* XPM */
static char * tasklist_stick_xpm[] = {
"20 20 34 1",
" 	c None",
".	c #000000",
"+	c #D3C9B2",
"@	c #C1B292",
"#	c #DBD2C0",
"$	c #DFD8C8",
"%	c #E5DFD2",
"&	c #DFD7C6",
"*	c #E8E2D7",
"=	c #CDC5AA",
"-	c #FFFFFF",
";	c #9C9077",
">	c #746F5F",
",	c #555144",
"'	c #F3F2EC",
")	c #534F42",
"!	c #8A8069",
"~	c #47443A",
"{	c #434136",
"]	c #A89B7F",
"^	c #E5E1D4",
"/	c #585447",
"(	c #514D40",
"_	c #877C66",
":	c #8E8977",
"<	c #656152",
"[	c #5F5A4C",
"}	c #E0DFDD",
"|	c #9F9B92",
"1	c #938E84",
"2	c #FBFAFA",
"3	c #D5CAB6",
"4	c #B3A588",
"5	c #92876F",
"                    ",
"        .....       ",
"       .+++@@.      ",
"      .#$%&+@@.     ",
"      .+**$++@.     ",
"       .+$%+@.      ",
"       .......      ",
"       .=-;>,.      ",
"       .='>>).      ",
"      ..=-!>~{.     ",
"     .].=^>>/(@.    ",
"     .@_:-]<[]@.    ",
"     .]$}|[[;@].    ",
"      .123@@@].     ",
"       ..445..      ",
"         ...        ",
"          .         ",
"          .         ",
"          .         ",
"                    "};
/* XPM */
static char * tasklist_unshade_xpm[] = {
"16 16 6 1",
" 	c None",
".	c #A8444C",
"+	c #000000",
"@	c #D89C90",
"#	c #D06458",
"$	c #843424",
"                ",
" ++++++++++++++ ",
" +@..........$+ ",
" ++++++++++++++ ",
"                ",
"       ++       ",
"       ++       ",
"       ++       ",
"       ++       ",
"     ++++++     ",
"      ++++      ",
"       ++       ",
"                ",
"                ",
"                ",
"                "};
/* XPM */
static char * tasklist_unstick_xpm[] = {
"20 20 41 1",
" 	c None",
".	c #000000",
"+	c #A89B7F",
"@	c #C1B292",
"#	c #938E84",
"$	c #DFD8C8",
"%	c #877C66",
"&	c #ADA89A",
"*	c #A49F91",
"=	c #FBFAFA",
"-	c #E0DFDD",
";	c #8E8977",
">	c #CDC5AA",
",	c #716E64",
"'	c #B5B0A0",
")	c #B9B4A4",
"!	c #888479",
"~	c #B3A588",
"{	c #D5CAB6",
"]	c #9F9B92",
"^	c #FFFFFF",
"/	c #E5E1D4",
"(	c #F3F2EC",
"_	c #5F5A4C",
":	c #746F5F",
"<	c #8A8069",
"[	c #9C9077",
"}	c #B5B1A2",
"|	c #B2AE9F",
"1	c #92876F",
"2	c #656152",
"3	c #585447",
"4	c #47443A",
"5	c #534F42",
"6	c #555144",
"7	c #ABA698",
"8	c #78756B",
"9	c #514D40",
"0	c #434136",
"a	c #9D998C",
"b	c #9B978A",
"                    ",
"                    ",
"                    ",
"                    ",
"                    ",
"       ...          ",
"      .+@+.    ..   ",
"     .#$%......&*.  ",
"     .=-;>>>>.,')!. ",
"    .~{]^/^(^.*''*. ",
" ....~@_+:<:[.}|'*. ",
"    .1@_2::::.*''*. ",
"     .@[_3456.!)78. ",
"     .+@+90....ab.  ",
"      .+@@.    ..   ",
"       ...          ",
"                    ",
"                    ",
"                    ",
"                    "};

/* XPM */
static char * tasklist_kill_xpm[] = {
"20 20 121 2",
"  	c None",
". 	c #000000",
"+ 	c #020202",
"@ 	c #030303",
"# 	c #1D1D1D",
"$ 	c #999999",
"% 	c #949494",
"& 	c #8D8D8D",
"* 	c #707070",
"= 	c #494949",
"- 	c #151515",
"; 	c #010101",
"> 	c #767676",
", 	c #A0A0A0",
"' 	c #C1C1C1",
") 	c #C0C0C0",
"! 	c #B4B4B4",
"~ 	c #9F9F9F",
"{ 	c #ACACAC",
"] 	c #868686",
"^ 	c #696969",
"/ 	c #515151",
"( 	c #E1E1E1",
"_ 	c #E3E3E3",
": 	c #DDDDDD",
"< 	c #D5D5D5",
"[ 	c #C4C4C4",
"} 	c #A6A6A6",
"| 	c #9B9B9B",
"1 	c #8F8F8F",
"2 	c #6A6A6A",
"3 	c #424242",
"4 	c #D8D8D8",
"5 	c #F9F9F9",
"6 	c #F7F7F7",
"7 	c #E8E8E8",
"8 	c #DFDFDF",
"9 	c #CDCDCD",
"0 	c #CACACA",
"a 	c #B2B2B2",
"b 	c #787878",
"c 	c #4B4B4B",
"d 	c #676767",
"e 	c #ABABAB",
"f 	c #EBEBEB",
"g 	c #555555",
"h 	c #A7A7A7",
"i 	c #D7D7D7",
"j 	c #5A5A5A",
"k 	c #2C2C2C",
"l 	c #2B2B2B",
"m 	c #3C3C3C",
"n 	c #B3B3B3",
"o 	c #535353",
"p 	c #131313",
"q 	c #121212",
"r 	c #202020",
"s 	c #CECECE",
"t 	c #4A4A4A",
"u 	c #111111",
"v 	c #0D0D0D",
"w 	c #0B0B0B",
"x 	c #4E4E4E",
"y 	c #7E7E7E",
"z 	c #434343",
"A 	c #191919",
"B 	c #0A0A0A",
"C 	c #050505",
"D 	c #414141",
"E 	c #EFEFEF",
"F 	c #3E3E3E",
"G 	c #060606",
"H 	c #040404",
"I 	c #242424",
"J 	c #353535",
"K 	c #929292",
"L 	c #575757",
"M 	c #595959",
"N 	c #F3F3F3",
"O 	c #CCCCCC",
"P 	c #6B6B6B",
"Q 	c #464646",
"R 	c #797979",
"S 	c #585858",
"T 	c #2D2D2D",
"U 	c #919191",
"V 	c #C7C7C7",
"W 	c #E9E9E9",
"X 	c #B6B6B6",
"Y 	c #323232",
"Z 	c #9A9A9A",
"` 	c #777777",
" .	c #262626",
"..	c #666666",
"+.	c #7F7F7F",
"@.	c #B8B8B8",
"#.	c #D9D9D9",
"$.	c #1A1A1A",
"%.	c #565656",
"&.	c #A4A4A4",
"*.	c #363636",
"=.	c #2E2E2E",
"-.	c #DBDBDB",
";.	c #4F4F4F",
">.	c #727272",
",.	c #A9A9A9",
"'.	c #DCDCDC",
").	c #DEDEDE",
"!.	c #C9C9C9",
"~.	c #7A7A7A",
"{.	c #474747",
"].	c #646464",
"^.	c #D2D2D2",
"/.	c #7B7B7B",
"(.	c #3A3A3A",
"_.	c #BFBFBF",
":.	c #3F3F3F",
"<.	c #D0D0D0",
"[.	c #C3C3C3",
"}.	c #B9B9B9",
"|.	c #A3A3A3",
"                                        ",
"              . . . + . @               ",
"          + # $ % $ & * = - .           ",
"        ; > , ' ) ! ~ { ] ^ / .         ",
"      . ^ $ ( _ : < [ } | 1 2 3 .       ",
"      . ^ 4 5 6 7 8 9 0 8 a b c .       ",
"    . d e f | g g h i < j k l c m .     ",
"    . j n o p p q r s t u v w # x .     ",
"    . x y z A B C D E F w G H I J .     ",
"    . g > K L M , N O % P Q R S T .     ",
"      . d U V W 6 X Y = Z U `  ..       ",
"      . ..+.@.#.W $.%.$.&.2 *.=..       ",
"        . ..+.0 -.$.) u | ;.l .         ",
"          . >.,.'.).!.~.$ {..           ",
"          . ' & ].^./.(._.:..           ",
"          . <.R B '.j . [./ .           ",
"          . }.].+ O = . |.Q .           ",
"            + .   H .   . .             ",
"                                        ",
"                                        "};
